=====
Usage
=====

The tool cellmaps_vnn allows to build Visible Neural Network (VNN) using hierarchy in CX2 format,
train the network with provided training data and perform predictions.

The tool can be used in two modes (as for the current state): **training** and **prediction**.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage_programmatically
   usage_command_line
   usage_via_docker
   example_usage_nest_vnn


